@@ -27,7 +27,7 @@ def plot_feature_importance(feature_importances, feature_names, title, xtick_ang
         plt.title(title + "\n" + 'importance marked by bar height')
     if feature_names is None or len(feature_names) <=0:
         feature_names = range(feature_importances.size)
-    plt.bar(feature_names, feature_importances, alpha=1.0, width=10)
+    plt.bar(feature_names, feature_importances, alpha=.8) # , width=2
     if xtick_angle is None:
         plt.xticks([])
     else:
